@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2021 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -25,6 +25,7 @@ import socket as socketlib
 import ssl
 import sys
 import time
+import errno
 
 
 from pathlib import Path
@@ -328,10 +329,11 @@ class SSHConnection(GvmConnection):
             # load the keys into paramiko and check if remote is in the list
             self._socket.load_host_keys(filename=self.known_hosts_file)
         except OSError as e:
-            raise GvmError(
-                'Something went wrong with reading '
-                f'the known_hosts file: {e}'
-            ) from None
+            if e.errno != errno.ENOENT:
+                raise GvmError(
+                    'Something went wrong with reading '
+                    f'the known_hosts file: {e}'
+                ) from None
         hostkeys = self._socket.get_host_keys()
         if not hostkeys.lookup(self.hostname):
             # Key not found, so connect to remote and fetch the key
@@ -465,6 +467,15 @@ class TLSConnection(GvmConnection):
         self._socket = self._new_socket()
         self._socket.connect((self.hostname, int(self.port)))
 
+    def disconnect(self):
+        """Close the SSL layer then disconnect from the remote server"""
+        try:
+            if self._socket is not None:
+                self._socket = self._socket.unwrap()
+        except OSError as e:
+            logger.debug("Connection closing error: %s", e)
+        return super(TLSConnection, self).disconnect()
+
 
 class UnixSocketConnection(GvmConnection):
     """
